aboutsummaryrefslogtreecommitdiff
path: root/google
diff options
context:
space:
mode:
authorGoogle APIs <noreply@google.com>2019-03-04 09:38:24 -0800
committerCopybara-Service <copybara-piper@google.com>2019-03-04 09:38:53 -0800
commit359c7016d48240abd77ff5a69fd286ccb8dccef3 (patch)
treed88327eb432d84dea2475c7da3d2fff53c41d82e /google
parent41d72d444fbe445f4da89e13be02078734fb7875 (diff)
downloadgoogleapis-359c7016d48240abd77ff5a69fd286ccb8dccef3.tar.gz
Synchronize new proto/yaml changes.
PiperOrigin-RevId: 236668629
Diffstat (limited to 'google')
-rw-r--r--google/cloud/securitycenter/v1/securitycenter_service.proto11
1 files changed, 8 insertions, 3 deletions
diff --git a/google/cloud/securitycenter/v1/securitycenter_service.proto b/google/cloud/securitycenter/v1/securitycenter_service.proto
index 59ce2b964..6c368bfd7 100644
--- a/google/cloud/securitycenter/v1/securitycenter_service.proto
+++ b/google/cloud/securitycenter/v1/securitycenter_service.proto
@@ -762,9 +762,10 @@ message ListFindingsResponse {
// The change in state of the finding.
//
// When querying across two points in time this describes
// the change in the finding between the two points: CHANGED, UNCHANGED, or
// ADDED. Findings can not be deleted, so these values represent the
// complete set of possible state changes. If there was no compare_duration
// supplied in the request the state change will be: UNUSED
enum StateChange {
// State change is unused, this is the canonical default for this enum.
@@ -780,6 +781,10 @@ message ListFindingsResponse {
// The finding was created between the points in time.
ADDED = 3;
+
+ // The finding at timestamp does not match the filter specified, but it
+ // did at timestamp - compare_duration.
+ REMOVED = 4;
}
// Finding matching the search request.
@@ -762,9 +762,10 @@ message ListFindingsResponse {
//
// When querying across two points in time this describes
- // the change in the finding between the two points: CHANGED, UNCHANGED, or
- // ADDED. Findings can not be deleted, so these values represent the
- // complete set of possible state changes. If there was no compare_duration
+ // the change in the finding between the two points: CHANGED, UNCHANGED,
+ // ADDED, or REMOVED. Findings can not be deleted, so REMOVED implies that
+ // the finding at timestamp does not match the filter specified, but it did
+ // at timestamp - compare_duration. If there was no compare_duration
// supplied in the request the state change will be: UNUSED
enum StateChange {